@@ -228,8 +228,13 @@ See `run-hooks'."
 		   "\\|\\(define-static-simple-method\\)"
 		   "\\|\\(define-param-method\\)"
 		   "\\|\\(define-static-param-method\\)"
-		   "\\|\\(define-generic-proc\\)"
+		   "\\|\\(define-simple-virtual-method\\)"
+		   "\\|\\(define-static-simple-virtual-method\\)"
+		   "\\|\\(define-param-virtual-method\\)"
+		   "\\|\\(define-static-param-virtual-method\\)"
+		   "\\|\\(define-virtual-gen-proc\\)"
 		   "\\|\\(define-simple-proc\\)"
+		   "\\|\\(define-main-proc\\)"
 		   "\\|\\(define-param-proc\\)"
 		   "\\|\\(define-param-proc-alt\\)"
 		   "\\|\\(define-proper-program\\)"
@@ -245,10 +250,26 @@ See `run-hooks'."
 		   "\\|\\(declare\\)"
 		   "\\|\\(declare-method\\)"
 		   "\\|\\(declare-static-method\\)"
+		   "\\|\\(declare-virtual-method\\)"
+		   "\\|\\(declare-static-virtual-method\\)"
+		   "\\|\\(declare-simple-method\\)"
+		   "\\|\\(declare-static-simple-method\\)"
+		   "\\|\\(declare-param-method\\)"
+		   "\\|\\(declare-static-param-method\\)"
+		   "\\|\\(declare-simple-virtual-method\\)"
+		   "\\|\\(declare-static-simple-virtual-method\\)"
+		   "\\|\\(declare-param-virtual-method\\)"
+		   "\\|\\(declare-static-param-virtual-method\\)"
 		   "\\|\\(declare-mutable\\)"
 		   "\\|\\(declare-volatile\\)"
+		   "\\|\\(include-methods\\)"
+		   "\\|\\(include-virtual-methods\\)"
+		   "\\|\\(include-static-virtual-methods\\)"
 		   "\\|\\(add-method\\)"
-		   "\\|\\(add-static-method\\)\\)"
+		   "\\|\\(add-static-method\\)"
+		   "\\|\\(add-virtual-method\\)"
+		   "\\|\\(add-static-virtual-method\\)"
+		   "\\|\\(add-param-method-alt\\)\\)"
 		   "\\>"
 		   ;; Any whitespace and declared object.
 		   "[ \t]*(?"
@@ -474,15 +495,20 @@ See `run-hooks'."
 (put '$define 'theme-d-indent-function 1)
 (put '$lambda 'theme-d-indent-function 1)
 (put '$let 'theme-d-indent-function 'theme-d-let-indent)
+(put 'add-method 'theme-d-indent-function 1)
+(put 'add-param-method-alt 'theme-d-indent-function 2)
 (put 'begin 'theme-d-indent-function 0)
 (put 'case 'theme-d-indent-function 1)
 ;; (put 'delay 'theme-d-indent-function 0)
+(put 'define-main-proc 'theme-d-indent-function 1)
 (put 'define-simple-method 'theme-d-indent-function 2)
 (put 'define-simple-proc 'theme-d-indent-function 2)
 (put 'define-param-proc 'theme-d-indent-function 3)
 (put 'define-param-method 'theme-d-indent-function 3)
 (put 'define-signature 'theme-d-indent-function 2)
 (put 'define-param-signature 'theme-d-indent-function 3)
+(put 'declare-virtual-method 'theme-d-indent-function 1)
+(put 'declare-static-virtual-method 'theme-d-indent-function 1)
 (put 'do 'theme-d-indent-function 2)
 (put 'exec/cc 'theme-d-indent-function 2)
 (put 'lambda 'theme-d-indent-function 1)
